@@ -9,15 +9,15 @@ class DeleteApi(object):
         self._influxdb_client = influxdb_client
         self._service = DefaultService(influxdb_client.api_client)
 
-    def delete(self, start: datetime, stop: object, predicate: object, bucket_id: str, org_id: str) -> None:
+    def delete(self, start: datetime, stop: object, predicate: object, bucket: str, org: str) -> None:
         """
         Delete Time series data from InfluxDB.
         :param start: start time
         :param stop: stop time
         :param predicate: predicate
-        :param bucket_id: bucket id from which data will be deleted
-        :param org_id: organization id
+        :param bucket: bucket id or name from which data will be deleted
+        :param org: organization id or name
         :return:
         """
         predicate_request = DeletePredicateRequest(start=start, stop=stop, predicate=predicate)
-        return self._service.delete_post(delete_predicate_request=predicate_request, bucket_id=bucket_id, org_id=org_id)
+        return self._service.delete_post(delete_predicate_request=predicate_request, bucket=bucket, org=org)
