@@ -1,13 +1,12 @@
 # coding: utf-8
 import logging
+import os
 from datetime import timedelta
 from enum import Enum
 from random import random
 from time import sleep
 from typing import Union, List
 
-import os
-
 import rx
 from rx import operators as ops, Observable
 from rx.scheduler import ThreadPoolScheduler
@@ -172,8 +171,9 @@ class WriteApi(AbstractClient):
                         ops.map(lambda xs: _BatchItem(key=group.key, data=_body_reduce(xs), size=len(xs))))),
                     ops.merge_all())),
                 # Write data into InfluxDB (possibility to retry if its fail)
-                ops.map(mapper=lambda batch: self._retryable(data=batch, delay=self._jitter_delay())),  #
-                ops.merge_all())\
+                ops.filter(lambda batch: batch.size > 0),
+                ops.map(mapper=lambda batch: self._retryable(data=batch, delay=self._jitter_delay())),
+                ops.merge_all()) \
                 .subscribe(self._on_next, self._on_error, self._on_complete)
 
         else:
@@ -183,21 +183,23 @@ class WriteApi(AbstractClient):
     def write(self, bucket: str, org: str = None,
               record: Union[
                   str, List['str'], Point, List['Point'], dict, List['dict'], bytes, List['bytes'], Observable] = None,
-              write_precision: WritePrecision = DEFAULT_WRITE_PRECISION) -> None:
+              write_precision: WritePrecision = DEFAULT_WRITE_PRECISION, **kwargs) -> None:
         """
         Writes time-series data into influxdb.
 
         :param str org: specifies the destination organization for writes; take either the ID or Name interchangeably; if both orgID and org are specified, org takes precedence. (required)
         :param str bucket: specifies the destination bucket for writes (required)
         :param WritePrecision write_precision: specifies the precision for the unix timestamps within the body line-protocol
-        :param record: Points, line protocol, RxPY Observable to write
+        :param record: Points, line protocol, Pandas DataFrame, RxPY Observable to write
+        :param data_frame_measurement_name: name of measurement for writing Pandas DataFrame
+        :param data_frame_tag_columns: list of DataFrame columns which are tags, rest columns will be fields
 
         """
 
         if org is None:
             org = self._influxdb_client.org
 
-        if self._point_settings.defaultTags and record:
+        if self._point_settings.defaultTags and record is not None:
             for key, val in self._point_settings.defaultTags.items():
                 if isinstance(record, dict):
                     record.get("tags")[key] = val
@@ -209,9 +211,10 @@ class WriteApi(AbstractClient):
                             r.tag(key, val)
 
         if self._write_options.write_type is WriteType.batching:
-            return self._write_batching(bucket, org, record, write_precision)
+            return self._write_batching(bucket, org, record,
+                                        write_precision, **kwargs)
 
-        final_string = self._serialize(record, write_precision)
+        final_string = self._serialize(record, write_precision, **kwargs)
 
         _async_req = True if self._write_options.write_type == WriteType.asynchronous else False
 
@@ -235,7 +238,7 @@ class WriteApi(AbstractClient):
             self._disposable = None
         pass
 
-    def _serialize(self, record, write_precision) -> bytes:
+    def _serialize(self, record, write_precision, **kwargs) -> bytes:
         _result = b''
         if isinstance(record, bytes):
             _result = record
@@ -244,40 +247,96 @@ class WriteApi(AbstractClient):
             _result = record.encode("utf-8")
 
         elif isinstance(record, Point):
-            _result = self._serialize(record.to_line_protocol(), write_precision=write_precision)
+            _result = self._serialize(record.to_line_protocol(), write_precision, **kwargs)
 
         elif isinstance(record, dict):
             _result = self._serialize(Point.from_dict(record, write_precision=write_precision),
-                                      write_precision=write_precision)
+                                      write_precision, **kwargs)
+        elif 'DataFrame' in type(record).__name__:
+            _result = self._serialize(self._data_frame_to_list_of_points(record,
+                                                                         precision=write_precision, **kwargs),
+                                      write_precision,
+                                      **kwargs)
+
         elif isinstance(record, list):
-            _result = b'\n'.join([self._serialize(item, write_precision=write_precision) for item in record])
+            _result = b'\n'.join([self._serialize(item, write_precision,
+                                                  **kwargs) for item in record])
 
         return _result
 
-    def _write_batching(self, bucket, org, data, precision=DEFAULT_WRITE_PRECISION):
+    def _write_batching(self, bucket, org, data,
+                        precision=DEFAULT_WRITE_PRECISION,
+                        **kwargs):
         _key = _BatchItemKey(bucket, org, precision)
         if isinstance(data, bytes):
             self._subject.on_next(_BatchItem(key=_key, data=data))
 
         elif isinstance(data, str):
-            self._write_batching(bucket, org, data.encode("utf-8"), precision)
+            self._write_batching(bucket, org, data.encode("utf-8"),
+                                 precision, **kwargs)
 
         elif isinstance(data, Point):
-            self._write_batching(bucket, org, data.to_line_protocol(), precision)
+            self._write_batching(bucket, org, data.to_line_protocol(),
+                                 precision, **kwargs)
 
         elif isinstance(data, dict):
-            self._write_batching(bucket, org, Point.from_dict(data, write_precision=precision), precision)
+            self._write_batching(bucket, org, Point.from_dict(data, write_precision=precision),
+                                 precision, **kwargs)
+
+        elif 'DataFrame' in type(data).__name__:
+            self._write_batching(bucket, org, self._data_frame_to_list_of_points(data, precision, **kwargs),
+                                 precision, **kwargs)
 
         elif isinstance(data, list):
             for item in data:
-                self._write_batching(bucket, org, item, precision)
+                self._write_batching(bucket, org, item, precision, **kwargs)
 
         elif isinstance(data, Observable):
-            data.subscribe(lambda it: self._write_batching(bucket, org, it, precision))
+            data.subscribe(lambda it: self._write_batching(bucket, org, it, precision, **kwargs))
             pass
 
         return None
 
+    def _data_frame_to_list_of_points(self, data_frame, precision, **kwargs):
+        from ..extras import pd
+        if not isinstance(data_frame, pd.DataFrame):
+            raise TypeError('Must be DataFrame, but type was: {0}.'
+                            .format(type(data_frame)))
+
+        if 'data_frame_measurement_name' not in kwargs:
+            raise TypeError('"data_frame_measurement_name" is a Required Argument')
+
+        if isinstance(data_frame.index, pd.PeriodIndex):
+            data_frame.index = data_frame.index.to_timestamp()
+        else:
+            data_frame.index = pd.to_datetime(data_frame.index)
+
+        if data_frame.index.tzinfo is None:
+            data_frame.index = data_frame.index.tz_localize('UTC')
+
+        data = []
+
+        for c, (row) in enumerate(data_frame.values):
+            point = Point(measurement_name=kwargs.get('data_frame_measurement_name'))
+
+            for count, (value) in enumerate(row):
+                column = data_frame.columns[count]
+                data_frame_tag_columns = kwargs.get('data_frame_tag_columns')
+                if data_frame_tag_columns and column in data_frame_tag_columns:
+                    point.tag(column, value)
+                else:
+                    point.field(column, value)
+
+            point.time(data_frame.index[c], precision)
+
+            if self._point_settings.defaultTags:
+                for key, val in self._point_settings.defaultTags.items():
+                    point.tag(key, val)
+
+            data.append(point)
+
+        return data
+
     def _http(self, batch_item: _BatchItem):
 
         logger.debug("Write time series data into InfluxDB: %s", batch_item)
