@@ -378,6 +378,62 @@ class BatchingWriteTest(BaseTest):
         self.assertEqual(1, len(requests))
         self.assertEqual(f'influxdb-client-python/{influxdb_client.__version__}', requests[0].headers['User-Agent'])
 
+    def test_to_low_flush_interval(self):
+
+        self._write_client.__del__()
+        self._write_client = WriteApi(influxdb_client=self.influxdb_client,
+                                      write_options=WriteOptions(batch_size=8,
+                                                                 flush_interval=1,
+                                                                 jitter_interval=1000))
+
+        httpretty.register_uri(httpretty.POST, uri="http://localhost/api/v2/write", status=204)
+
+        for i in range(50):
+            val_one = float(i)
+            val_two = float(i) + 0.5
+            point_one = Point("OneMillis").tag("sensor", "sensor1").field("PSI", val_one).time(time=i)
+            point_two = Point("OneMillis").tag("sensor", "sensor2").field("PSI", val_two).time(time=i)
+
+            self._write_client.write("my-bucket", "my-org", [point_one, point_two])
+            time.sleep(0.1)
+
+        self._write_client.__del__()
+
+        _requests = httpretty.httpretty.latest_requests
+
+        for _request in _requests:
+            body = _request.parsed_body
+            self.assertTrue(body, msg="Parsed body should be not empty " + str(_request))
+
+        httpretty.reset()
+
+    def test_batching_data_frame(self):
+        from influxdb_client.extras import pd
+
+        httpretty.register_uri(httpretty.POST, uri="http://localhost/api/v2/write", status=204)
+        httpretty.register_uri(httpretty.POST, uri="http://localhost/api/v2/write", status=204)
+
+        data_frame = pd.DataFrame(data=[["coyote_creek", 1.0], ["coyote_creek", 2.0],
+                                        ["coyote_creek", 3.0], ["coyote_creek", 4.0]],
+                                  index=[1, 2, 3, 4],
+                                  columns=["location", "level water_level"])
+
+        self._write_client.write("my-bucket", "my-org", record=data_frame,
+                                 data_frame_measurement_name='h2o_feet',
+                                 data_frame_tag_columns=['location'])
+
+        time.sleep(1)
+
+        _requests = httpretty.httpretty.latest_requests
+
+        self.assertEqual(2, len(_requests))
+        _request1 = "h2o_feet,location=coyote_creek level\\ water_level=1.0 1\n" \
+                    "h2o_feet,location=coyote_creek level\\ water_level=2.0 2"
+        _request2 = "h2o_feet,location=coyote_creek level\\ water_level=3.0 3\n" \
+                    "h2o_feet,location=coyote_creek level\\ water_level=4.0 4"
+
+        self.assertEqual(_request1, _requests[0].parsed_body)
+        self.assertEqual(_request2, _requests[1].parsed_body)
 
 if __name__ == '__main__':
     unittest.main()
